@@ -206,6 +206,14 @@ public final class CertificateVerifier
             {
                 // happens with 021496.pdf because OCSP responder no longer exists
                 LOG.warn("IOException trying OCSP, will try CRL", ex);
+                LOG.warn("Certificate# to check: " + cert.getSerialNumber().toString(16));
+                CRLVerifier.verifyCertificateCRLs(cert, signDate, additionalCerts);
+            }
+            catch (OCSPException ex)
+            {
+                // happens with QV_RCA1_RCA3_CPCPS_V4_11.pdf
+                LOG.warn("OCSPException trying OCSP, will try CRL", ex);
+                LOG.warn("Certificate# to check: " + cert.getSerialNumber().toString(16));
                 CRLVerifier.verifyCertificateCRLs(cert, signDate, additionalCerts);
             }
         }
