@@ -67,7 +67,7 @@ public class PDButtonTest
         PDButton buttonField = new PDCheckBox(acroForm);
         
         assertEquals(buttonField.getFieldType(), buttonField.getCOSObject().getNameAsString(COSName.FT));
-        assertEquals(buttonField.getFieldType(), "Btn");
+        assertEquals("Btn", buttonField.getFieldType());
         assertFalse(buttonField.isPushButton());
         assertFalse(buttonField.isRadioButton());
     }
@@ -78,7 +78,7 @@ public class PDButtonTest
         PDButton buttonField = new PDPushButton(acroForm);
         
         assertEquals(buttonField.getFieldType(), buttonField.getCOSObject().getNameAsString(COSName.FT));
-        assertEquals(buttonField.getFieldType(), "Btn");
+        assertEquals("Btn", buttonField.getFieldType());
         assertTrue(buttonField.isPushButton());
         assertFalse(buttonField.isRadioButton());
     }
@@ -89,7 +89,7 @@ public class PDButtonTest
         PDButton buttonField = new PDRadioButton(acroForm);
         
         assertEquals(buttonField.getFieldType(), buttonField.getCOSObject().getNameAsString(COSName.FT));
-        assertEquals(buttonField.getFieldType(), "Btn");
+        assertEquals("Btn", buttonField.getFieldType());
         assertTrue(buttonField.isRadioButton());
         assertFalse(buttonField.isPushButton());
     }
@@ -203,8 +203,8 @@ public class PDButtonTest
     {
         PDCheckBox checkbox = (PDCheckBox) acrobatAcroForm.getField("Checkbox");
         assertNotNull(checkbox);
-        assertEquals(checkbox.getOnValue(), "Yes");
-        assertEquals(checkbox.getOnValues().size(), 1);
+        assertEquals("Yes", checkbox.getOnValue());
+        assertEquals(1, checkbox.getOnValues().size());
         assertTrue(checkbox.getOnValues().contains("Yes"));
     }
     
@@ -243,55 +243,55 @@ public class PDButtonTest
 
         checkbox.setValue("Yes");
         assertEquals(checkbox.getValueAsString(), ((PDCheckBox) checkbox).getOnValue());
-        assertEquals(((PDCheckBox) checkbox).isChecked(), true);
-        assertEquals(checkbox.getCOSObject().getDictionaryObject(COSName.AS), COSName.YES);
+        assertEquals(true, ((PDCheckBox) checkbox).isChecked());
+        assertEquals(COSName.YES, checkbox.getCOSObject().getDictionaryObject(COSName.AS));
 
         checkbox.setValue("Off");
-        assertEquals(checkbox.getValueAsString(), COSName.Off.getName());
-        assertEquals(((PDCheckBox) checkbox).isChecked(), false);
-        assertEquals(checkbox.getCOSObject().getDictionaryObject(COSName.AS), COSName.Off);
+        assertEquals(COSName.Off.getName(), checkbox.getValueAsString());
+        assertEquals(false, ((PDCheckBox) checkbox).isChecked());
+        assertEquals(COSName.Off, checkbox.getCOSObject().getDictionaryObject(COSName.AS));
     }
     
     @Test
     public void testAcrobatCheckBoxGroupProperties() throws IOException
     {
         PDCheckBox checkbox = (PDCheckBox) acrobatAcroForm.getField("CheckboxGroup");
-        assertEquals(checkbox.getValue(), "Off");
-        assertEquals(checkbox.isChecked(), false);
+        assertEquals("Off", checkbox.getValue());
+        assertEquals(false, checkbox.isChecked());
 
         checkbox.check();
         assertEquals(checkbox.getValue(), checkbox.getOnValue());
-        assertEquals(checkbox.isChecked(), true);
-        
-        assertEquals(checkbox.getOnValues().size(), 3);
+        assertEquals(true, checkbox.isChecked());
+
+        assertEquals(3, checkbox.getOnValues().size());
         assertTrue(checkbox.getOnValues().contains("Option1"));
         assertTrue(checkbox.getOnValues().contains("Option2"));
         assertTrue(checkbox.getOnValues().contains("Option3"));
-        
+
         // test a value which sets one of the individual checkboxes within the group
         checkbox.setValue("Option1");
-        assertEquals("Option1",checkbox.getValue());
-        assertEquals("Option1",checkbox.getValueAsString());
+        assertEquals("Option1", checkbox.getValue());
+        assertEquals("Option1", checkbox.getValueAsString());
 
         // ensure that for the widgets representing the individual checkboxes
         // the AS entry has been set
-        assertEquals("Option1",checkbox.getWidgets().get(0).getAppearanceState().getName());
-        assertEquals("Off",checkbox.getWidgets().get(1).getAppearanceState().getName());
-        assertEquals("Off",checkbox.getWidgets().get(2).getAppearanceState().getName());
-        assertEquals("Off",checkbox.getWidgets().get(3).getAppearanceState().getName());
-        
+        assertEquals("Option1", checkbox.getWidgets().get(0).getAppearanceState().getName());
+        assertEquals("Off", checkbox.getWidgets().get(1).getAppearanceState().getName());
+        assertEquals("Off", checkbox.getWidgets().get(2).getAppearanceState().getName());
+        assertEquals("Off", checkbox.getWidgets().get(3).getAppearanceState().getName());
+
         // test a value which sets two of the individual chekboxes within the group
         // as the have the same name entry for being checked
         checkbox.setValue("Option3");
-        assertEquals("Option3",checkbox.getValue());
-        assertEquals("Option3",checkbox.getValueAsString());
-        
+        assertEquals("Option3", checkbox.getValue());
+        assertEquals("Option3", checkbox.getValueAsString());
+
         // ensure that for both widgets representing the individual checkboxes
         // the AS entry has been set
-        assertEquals("Off",checkbox.getWidgets().get(0).getAppearanceState().getName());
-        assertEquals("Off",checkbox.getWidgets().get(1).getAppearanceState().getName());
-        assertEquals("Option3",checkbox.getWidgets().get(2).getAppearanceState().getName());
-        assertEquals("Option3",checkbox.getWidgets().get(3).getAppearanceState().getName());
+        assertEquals("Off", checkbox.getWidgets().get(0).getAppearanceState().getName());
+        assertEquals("Off", checkbox.getWidgets().get(1).getAppearanceState().getName());
+        assertEquals("Option3", checkbox.getWidgets().get(2).getAppearanceState().getName());
+        assertEquals("Option3", checkbox.getWidgets().get(3).getAppearanceState().getName());
     }
     
     @Test
@@ -360,7 +360,7 @@ public class PDButtonTest
     {
         PDRadioButton radioButton = (PDRadioButton) acrobatAcroForm.getField("RadioButtonGroup");
         assertNotNull(radioButton);
-        assertEquals(radioButton.getOnValues().size(), 2);
+        assertEquals(2, radioButton.getOnValues().size());
         assertTrue(radioButton.getOnValues().contains("RadioButton01"));
         assertTrue(radioButton.getOnValues().contains("RadioButton02"));
     }
@@ -372,21 +372,21 @@ public class PDButtonTest
 
         // Set value so that first radio button option is selected
         radioButton.setValue("RadioButton01");
-        assertEquals(radioButton.getValue(), "RadioButton01");
+        assertEquals("RadioButton01", radioButton.getValue());
         // First option shall have /RadioButton01, second shall have /Off
-        assertEquals(radioButton.getWidgets().get(0).getCOSObject().getDictionaryObject(COSName.AS),
-                COSName.getPDFName("RadioButton01"));
-        assertEquals(radioButton.getWidgets().get(1).getCOSObject().getDictionaryObject(COSName.AS),
-                COSName.Off);
+        assertEquals(COSName.getPDFName("RadioButton01"),
+                radioButton.getWidgets().get(0).getCOSObject().getDictionaryObject(COSName.AS));
+        assertEquals(COSName.Off,
+                radioButton.getWidgets().get(1).getCOSObject().getDictionaryObject(COSName.AS));
 
         // Set value so that second radio button option is selected
         radioButton.setValue("RadioButton02");
-        assertEquals(radioButton.getValue(), "RadioButton02");
+        assertEquals("RadioButton02", radioButton.getValue());
         // First option shall have /Off, second shall have /RadioButton02
-        assertEquals(radioButton.getWidgets().get(0).getCOSObject().getDictionaryObject(COSName.AS),
-                COSName.Off);
-        assertEquals(radioButton.getWidgets().get(1).getCOSObject().getDictionaryObject(COSName.AS),
-                COSName.getPDFName("RadioButton02"));
+        assertEquals(COSName.Off,
+                radioButton.getWidgets().get(0).getCOSObject().getDictionaryObject(COSName.AS));
+        assertEquals(COSName.getPDFName("RadioButton02"),
+                radioButton.getWidgets().get(1).getCOSObject().getDictionaryObject(COSName.AS));
     }
     
     @Test
@@ -396,21 +396,21 @@ public class PDButtonTest
 
         // Set value so that first radio button option is selected
         radioButton.setValue("RadioButton01");
-        assertEquals(radioButton.getValueAsString(), "RadioButton01");
+        assertEquals("RadioButton01", radioButton.getValueAsString());
         // First option shall have /RadioButton01, second shall have /Off
-        assertEquals(radioButton.getWidgets().get(0).getCOSObject().getDictionaryObject(COSName.AS),
-                COSName.getPDFName("RadioButton01"));
-        assertEquals(radioButton.getWidgets().get(1).getCOSObject().getDictionaryObject(COSName.AS),
-                COSName.Off);
+        assertEquals(COSName.getPDFName("RadioButton01"),
+                radioButton.getWidgets().get(0).getCOSObject().getDictionaryObject(COSName.AS));
+        assertEquals(COSName.Off,
+                radioButton.getWidgets().get(1).getCOSObject().getDictionaryObject(COSName.AS));
 
         // Set value so that second radio button option is selected
         radioButton.setValue("RadioButton02");
-        assertEquals(radioButton.getValueAsString(), "RadioButton02");
+        assertEquals("RadioButton02", radioButton.getValueAsString());
         // First option shall have /Off, second shall have /RadioButton02
-        assertEquals(radioButton.getWidgets().get(0).getCOSObject().getDictionaryObject(COSName.AS),
-                COSName.Off);
-        assertEquals(radioButton.getWidgets().get(1).getCOSObject().getDictionaryObject(COSName.AS),
-                COSName.getPDFName("RadioButton02"));
+        assertEquals(COSName.Off,
+                radioButton.getWidgets().get(0).getCOSObject().getDictionaryObject(COSName.AS));
+        assertEquals(COSName.getPDFName("RadioButton02"),
+                radioButton.getWidgets().get(1).getCOSObject().getDictionaryObject(COSName.AS));
     }
     
     @Test(expected=IllegalArgumentException.class)
